SystemOrganization addCategory: #ConfigurationOfMetacello!

Object subclass: #ConfigurationOfMetacello
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfMetacello'!

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 10/31/2009 13:44'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 12/01/2009 16:06'!
ensureMetacello
	"Minimum package versions from which to boot Metacello. Corresponds to version 1.0-beta.15"

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:gofer |
			gofer new
				url: 'http://seaside.gemstone.com/ss/metacello';
				addVersion: 'Metacello-Core-dkh.302';
				addVersion: 'Metacello-MC-dkh.258';
				load ]]! !

!ConfigurationOfMetacello class methodsFor: 'metacello tool support' stamp: 'dkh 10/31/2009 13:44'!
isMetacelloConfig

	^true! !

!ConfigurationOfMetacello class methodsFor: 'metacello tool support' stamp: 'dkh 11/03/2009 11:04'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfMetacello class methodsFor: 'loading' stamp: 'dkh 10/31/2009 13:44'!
loadLatestPackages
	"self loadLatestPackages"

	| project |
	project := self project.
	^(project latestVersion: #baseline) load: 'ALL'! !

!ConfigurationOfMetacello class methodsFor: 'loading' stamp: 'dkh 10/31/2009 13:44'!
loadLatestVersion
	"self loadLatestVersion"

	| project |
	project := self project.
	project updateProject.
	^project latestVersion load: 'ALL'! !

!ConfigurationOfMetacello class methodsFor: 'metacello tool support' stamp: 'dkh 11/3/2009 10:16'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfMetacello class methodsFor: 'accessing' stamp: 'dkh 10/31/2009 13:44'!
project

	^self new project! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 11/05/2009 11:26'!
baseline10beta00: spec 
	<version: '1.0-beta.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Default configuration ... loads latest versions of all packages'.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec 
			package: 'Gofer' with: [
				spec repository: 'http://source.lukas-renggli.ch/flair' ];
			package: 'Metacello-Core' with: [
				spec includes: #('Metacello-MC' 'Metacello-Platform') ];
			package: 'Metacello-MC' with: [
				spec requires: #('Gofer') ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC') ];
			package: 'Metacello-ConfigTests' with: [
				spec requires: #('Metacello-MC') ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC') ];
			package: 'Metacello-ReferenceTests' with: [
				spec requires: #('Metacello-Reference') ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform') ].
		spec
			group: 'default' with: #('Metacello-Core' 'Metacello-Reference');
			group: 'UI' with: #('Metacello-Core' 'OB-Metacello'); 
			group: 'Tests' with: #('Metacello-ConfigTests' 'Metacello-ReferenceTests') ].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone'].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo'].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak' ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 11/05/2009 11:26'!
baseline10beta03: spec 
	<version: '1.0-beta.3-baseline' imports: #('1.0-beta.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Extensions to 1.0-beta.0-baseline: 
- ''default'' group is just the core ... class-side loaders load ''ALL'' by default
- pull in some old tests that still apply
- combine Metacello-ConfigTests into Metacello-TestsMC
- rename Metacello-ReferenceTests to Metacello-TestsReference
- recast tutorial to new API
- add Samples group (Metacello-Configuration [duh] and Seaside-Metacello-Configuration'.

		spec 
			package: 'Metacello-Tutorial' with: [
				spec requires:  #('Metacello-Core'). ];
			package: 'Metacello-TestsCore' with: [
				spec requires:  #('Metacello-Core'). ];
			package: 'Metacello-TestsMC' with: [
				spec requires:  #('Metacello-Core'). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference') ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires:  #('Metacello-Tutorial'). ];
			removePackage: 'Metacello-ConfigTests';
			removePackage: 'Metacello-ReferenceTests';
			"SAMPLE"
			package: 'ConfigurationOfMetacello' with: [
				spec repository: 'http://seaside.gemstone.com/ss/metacello' ];
			"SAMPLE"
			package: 'Seaside-Metacello-Configuration' with: [
				spec repository: 'http://seaside.gemstone.com/ss/Seaside30' ].
		spec
			group: 'default' overrides: #('Metacello-Core');
			group: 'Samples' with: #('Metacello-Configuration' 'Seaside-Metacello-Configuration');
			group: 'Tests' overrides: 
				#('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC'
				  'Metacello-TestsReference'). ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 11/05/2009 11:26'!
baseline10beta05: spec 
	<version: '1.0-beta.5-baseline' imports: #('1.0-beta.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Extensions to 1.0-beta.3-baseline: 
- Samples group includes Seaside-Metacello-Configuration and GemTools-Configuraton (Metacello-Configuration should not be included ... it is always present)'.

		spec 
			package: 'GemTools-Configuraton' with: [
				spec repository: 'http://seaside.gemstone.com/ss/GLASSClient' ];
			removePackage: 'ConfigurationOfMetacello'.
		spec
			group: 'Samples' overrides: 
				#('Seaside-Metacello-Configuration' 'GemTools-Configuraton' ) ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 10/31/2009 21:16'!
baseline10beta11: spec 
	<version: '1.0-beta.11-baseline' imports: #('1.0-beta.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Removing Samples completely... Confusing I think'.

		spec 
			removePackage: 'Seaside-Metacello-Configuration';
			removePackage: 'GemTools-Configuraton';
			removePackage: 'ConfigurationOfMetacello'.
		spec
			removeGroup: 'Samples'].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 11/05/2009 11:35'!
baseline10beta13: spec 
	<version: '1.0-beta.13-baseline' imports: #('1.0-beta.11-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'fix Metacello-MC dependency'.

		spec 
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core') ];
			yourself].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 11/10/2009 10:15'!
baseline10beta14: spec 
	<version: '1.0-beta.14-baseline' imports: #('1.0-beta.13-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'switch gofer repositories'.

		spec 
			package: 'Gofer' with: [
				spec repository: 'http://source.lukas-renggli.ch/gofer' ];
			yourself].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 12/01/2009 16:07'!
baseline10beta16: spec 
	<version: '1.0-beta.16-baseline' imports: #('1.0-beta.14-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'switch gofer repositories again ... use copy in Metacello going forward'.

		spec 
			package: 'Gofer' with: [
				spec repository: 'http://seaside.gemstone.com/ss/metacello' ];
			yourself].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 12/7/2009 15:38'!
baseline10beta17: spec 
	<version: '1.0-beta.17-baseline' imports: #('1.0-beta.16-baseline')>
	
	spec for: #pharo do: [
		spec 
			package: 'Metacello-TestsPlatform' with: [
				spec
					requires: #('Metacello-Platform');
					file: 'Metacello-TestsPlatform.pharo'];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform')].
		
! !

!ConfigurationOfMetacello methodsFor: 'accessing' stamp: 'dkh 10/31/2009 13:44'!
project

	^ project ifNil: [ | constructor |
		self class ensureMetacello.
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project ]! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta0: spec
	<version: '1.0-beta.0' imports: #('1.0-beta.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Beta release introducing the shiny new API'.
		spec author: 'dkh'.
		spec timestamp: '10/9/2009 14:13'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.64';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.266';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.194';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.11';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.24';
			package: 'Metacello-ConfigTests' with: 'Metacello-ConfigTests-dkh.6';
			package: 'Metacello-ReferenceTests' with: 'Metacello-ReferenceTests-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.1'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta10: spec
	<version: '1.0-beta.10' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- GemStone-specific mods
- improve error message for missing import
- fix a couple of bugs in spawn new version
- if versionString is not specified in project reference, use #latestVersion of the project
- ''Update Package Method'' command updates the versionString for project reference to #currentVersion of the project
- ''Spawn New Version'' command spawns entry for proejct reference using #currentVersion of the project
- latest version of configuration package is loaded if the project reference refers to a version whose blessing is #development
- refactor #saveProject
- add #transact: to platform to support GemStone optional transactions
- define querying protocol (public access)
- use literal arrays instead of array constructors _everywhere_
- clean up printing
- refine querying API
- extend tutorial to cover querying API
'.
		spec author: 'dkh'.
		spec timestamp: '10/25/2009 11:34'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.285';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.222';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.29';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta11: spec
	<version: '1.0-beta.11' imports: #('1.0-beta.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- pick up latest Gofer package
- fix a project version loading bug
- printing fix
- fix an update packages bug
- adjust working version package name calculation
- fix current version package name calculation (http://code.google.com/p/metacello/issues/detail?id=4)
- doits bugfix
- fix a project reference project package bug
- add ''Load Latest Packages'' OB command
- remove Samples group
- save packages fix
- must be able to load packages that use directory repositories
- GemStone/GLASS support'.
		spec author: 'dkh'.
		spec timestamp: '10/31/09 11:03:31'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.76';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.294';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.239';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.32';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 11/3/2009 14:13'!
version10beta12: spec
	<version: '1.0-beta.12' imports: #('1.0-beta.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '-convert to using ConfigurationOfMetacello convention
- fix updateRepositories bug (update repository for loaded packages only)
- #repositoryFor:from: ... more GLASS support
- record last version loaded and list of packages loaded for each configuration (optional)
- use last list of packages loaded last when loading packages using tools
- improve promptForVersion algorithm to show current version and reduce version list to logical choices
- fix version number bug when version is empty. add tests
'.
		spec author: 'dkh'.
		spec timestamp: '11/03/09 11:07:27'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.76';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.295';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.245';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 11/5/2009 15:47'!
version10beta13: spec
	<version: '1.0-beta.13' imports: #('1.0-beta.13-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix a bug in current version algorithm
- improve current version algorithm
- pick up latest Gofer
'.
		spec author: 'dkh'.
		spec timestamp: '11/5/2009 15:46'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.77';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.300';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.249';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 11/16/2009 15:02'!
version10beta14: spec
	<version: '1.0-beta.14' imports: #('1.0-beta.14-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- improve handling of #development project references. Loader is responsible for ensuring that #development projects have latest package loaded.
- use latest Gofer
- skip automatic loading of packages when working copy #needsSaving
- better loop termination logic for packageSpecsInLoadOrder
- fix logic for loading latest version of a project when versionString is not set (use latest, then last version)
- collect repositories from just the packages (ignoring projects) ... affects load latest logic
- fix #promptForVersion: ... include #development versions in listing
- GemStone attributes, now may include: #gemstone #''gs2.x'' #''gs2.3.x'' #''gs2.4.x'' and #''gs3.x'' for finer grainded resolution of Stone version
- fix a package loading logic bug found by Doru (loading latest)'.
		spec author: 'dkh'.
		spec timestamp: '11/16/2009 15:02'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.302';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.256';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.38';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 11/21/2009 11:50'!
version10beta15: spec
	<version: '1.0-beta.15' imports: #('1.0-beta.14-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- fix ''Spawn New Version'' command
- tweak packageSpec shortcut printing - fine tune use of #overrides:'.
		spec author: 'dkh'.
		spec timestamp: '11/21/2009 11:49'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.302';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.258';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 12/01/2009 16:23'!
version10beta16: spec
	<version: '1.0-beta.16' imports: #('1.0-beta.16-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- put Gofer package in Metacello repository'.
		spec author: 'dkh'.
		spec timestamp: '12/01/09 16:22:42'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.302';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.259';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 12/7/2009 16:27'!
version10beta17: spec
	<version: '1.0-beta.17' imports: #('1.0-beta.17-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- fix a branch name problem for working copies
- fix Issue 12: http://code.google.com/p/metacello/issues/detail?id=12 Wait cursor during load
- fix Issue 14: http://code.google.com/p/metacello/issues/detail?id=14 Ftp repository for Pharo
- fix Issue 19: http://code.google.com/p/metacello/issues/detail?id=19 Bug in Spawn New Version
'.
		spec author: 'dkh'.
		spec timestamp: '12/7/2009 16:27'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.304';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.264';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.38';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #pharo do: [
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.9';
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.pharo-dkh.1'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta1: spec
	<version: '1.0-beta.1' imports: #('1.0-beta.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- change base version name for spawn method
- make sure author and timestamp included by spawn 
- fix file duplication for spawn method'.
		spec author: 'dkh'.
		spec timestamp: '10/10/2009 14:58'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.64';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.268';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.196';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.12';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.25';
			package: 'Metacello-ConfigTests' with: 'Metacello-ConfigTests-dkh.7';
			package: 'Metacello-ReferenceTests' with: 'Metacello-ReferenceTests-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.1'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta2: spec
	<version: '1.0-beta.2' imports: #('1.0-beta.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- change name of method used for bootstrapping to avoid confusion with methods actually used for loading.
- port to Squeak (Squeak3..10.10.2-Trunk-090912)'.
		spec author: 'dkh'.
		spec timestamp: '10/12/2009 13:31'.
		spec 
			package: 'Gofer' with: 'Gofer-dkh.65';
			package: 'Metacello-Core' with: [
				spec
					file: 'Metacello-Core-dkh.268';
					includes: #('Metacello-Reference' ) ];
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.197';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.12';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.25';
			package: 'Metacello-ConfigTests' with: 'Metacello-ConfigTests-dkh.7';
			package: 'Metacello-ReferenceTests' with: 'Metacello-ReferenceTests-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta3: spec
	<version: '1.0-beta.3' imports: #('1.0-beta.3-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- update to latest Gofer (Gofer-lr.67)
- fix a package overrides: bug
- pull in some old tests that still apply
- recast tutorial to new API plus tutorial tests
- fix platform attribute bug
- use strings instead of symbols for imports
- class-side project
- fix doit bug
- tools load ''ALL''
- deactive ''Update Repositories'' command'.
		spec author: 'dkh'.
		spec timestamp: '10/14/2009 10:06'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.67';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.271';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.201';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.13';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.12';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.1';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.2';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta4: spec
	<version: '1.0-beta.4' imports: #('1.0-beta.3-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- add platform attribute tests
- fix bug in project reference
- need to pass project into constructor (sometimes)
- duplication of #projectAttributes
- correct update package logic when package branches involved (<package name>.<branch name>-<author>.<version number>'.
		spec author: 'dkh'.
		spec timestamp: '10/15/2009 11:41'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.67';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.273';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.205';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.13';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.12';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.1';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.4';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta5: spec
	<version: '1.0-beta.5' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- GemStone port
- fix a bug in #project:copyFrom:with:
- rewrite null loader to use IVs for recording state
- get started on project ref tutorial
- ensure that imported versions exist
- use Gofer for direct loading of packages like from pojects, since configuration must be loaded immediately whether or not w are doing atomic/linear loads
- add project load test (coverage for Doru''s bug report)'.
		spec author: 'dkh'.
		spec timestamp: '10/18/2009 10:41'.
		spec 
			package: 'Gofer' with: 'Gofer-dkh.68';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.276';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.208';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.15';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.13';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.2';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.7';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.2'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.5'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta6: spec
	<version: '1.0-beta.6' imports: #('1.0-beta.5' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- asNumber throws Error (as of 10487) and Errors are not resumable
- bump up ensureMetacello methods to use versions from 1.0-beta.6
- use latest version of Gofer'.
		spec author: 'dkh'.
		spec timestamp: '10/19/2009 10:50'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.277';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.209';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.14'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta7: spec
	<version: '1.0-beta.7' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- finish project ref tutorial'.
		spec author: 'dkh'.
		spec timestamp: '10/19/2009 13:50'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.277';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.209';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.15';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.15';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.2';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.7';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.3'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.5'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta8: spec
	<version: '1.0-beta.8' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- protect senders of asNumber with error handler'.
		spec author: 'dkh'.
		spec timestamp: '10/20/2009 11:30'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.277';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.210';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.15';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.15';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.2';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.7';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.3'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.5'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 10/31/2009 13:44'!
version10beta9: spec
	<version: '1.0-beta.9' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- second cut at package query api for MetacellMCVersion requested by Simon, Read the method comments for documentation:
	- groups
	- packages
	- projects
	- packagesForSpecNamed:
	- allPackagesForSpecNamed:
- add #repository:username:password: to configuration API in support of repositories that require authentication.'.
		spec author: 'dkh'.
		spec timestamp: '10/22/2009 10:38'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.279';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.215';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.16';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.15';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.3';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.10';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.3'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.5'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !
